##  Filtering Fact Sheets and Relations in Diagrams
You can use filters to focus on relevant fact sheets and relations in a diagram and exclude unrelated elements. Filters work when you view or edit diagrams.
When you view a diagram, you can use filters to:
  * Focus on specific elements.
  * Explore parts of the architecture.
  * Create filtered views for presentations or reports.


When you apply filters, only fact sheets and relations that match your criteria appear in the diagram. Relations do not appear if any of their connected fact sheets are filtered out. Shapes outside fact sheet containers remain visible. Pending fact sheets do not appear. Filters stay active in exports and dashboard widgets.
To apply a filter to a diagram:
  1. Open a diagram to view.
  2. Select your filters in the filter bar or in the Filters menu.
![Diagram with filter options highlighted on the left and filtered nodes displayed.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fe0fc7a441014ae1f8b720df70987_LowRes.png)
  3. Choose Save to add the filters to the current diagram.
Alternatively, choose Save As to create a new diagram with the applied filters.


Applied filters are saved when you switch between viewing and editing. The system removes any unsaved filters.
**Note**
You can filter for specific fact sheets when viewing or editing a diagram. For information about using filters while creating diagrams, see [Selecting Fact Sheets by Filter in Free Draw](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a369c7a4410148ff4e12bcf658e03__select_by_filter) and [Selecting Fact Sheets by Filter in Data Flow](https://help.sap.com/docs/leanix/ea/data-flow?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759ae097a441014acff8ab536c79254__select_by_filter).
